## What

<!-- Brief description of changes -->

## Why

<!-- Why is this change needed? -->

## Test plan

- [ ] `ruff check .` passes
- [ ] `ruff format --check .` passes
- [ ] `pytest` passes
- [ ] Manual testing done

## Related issues

<!-- Closes #XX -->
